run_syscall_prog

Function run_syscall_prog 

pub(crate) fn run_syscall_prog<T>(
    prog: &ProgramMut<'_>,
    args: &mut T,
) -> Result<()>
Run a SEC(“syscall”) program with @args as its context.

Despite the name this is not a test run, it’s the supported way of invoking a syscall program from userspace.